@@ -27,7 +27,7 @@ class MathGenerateTests extends Maintenance {
 	public function __construct() {
 		parent::__construct();
 		$this->requireExtension( 'Math' );
-		$this->mDescription = 'Rebuilds the MathCoverage tests';
+		$this->addDescription( 'Rebuilds the MathCoverage tests' );
 		$this->addArg( 'page', "The page used for the testset generation.", false );
 		$this->addOption(
 			'offset', "If set the first n equations on the page are skipped", false, true, "o"
@@ -43,7 +43,7 @@ class MathGenerateTests extends Maintenance {
 			$article = new Article( $title );
 			$wikiText = $article->getPage()->getContent()->getNativeData();
 		} else {
-			if ( $title == self::REFERENCE_PAGE ) {
+			if ( $title->getPrefixedDBkey() === self::REFERENCE_PAGE ) {
 				$wgEnableScaryTranscluding = true;
 				$parser = new Parser();
 				$wikiText = $parser->interwikiTransclude( $title, 'raw' );
@@ -78,8 +78,12 @@ class MathGenerateTests extends Maintenance {
 		$i = 0;
 		foreach ( array_slice( $allEquations, $offset, $length, true ) as $input ) {
 			$output = MathRenderer::renderMath( $input[1], $input[2], 'png' );
-			$output = preg_replace( '#src="(.*?)/(([a-f]|\d)*).png"#', 'src="\2.png"', $output );
-			$parserTests[] = [ (string)$input[1], $output ];
+			$output = preg_replace( '#src="(.*?)/(([a-f]|\d)*)"#', 'src="\2"', $output );
+			$parserTests[] = [
+				'input' => (string)$input[1],
+				'params' => $input[2],
+				'output' => $output
+			];
 			$i++;
 			echo '.';
 		}
@@ -90,5 +94,5 @@ class MathGenerateTests extends Maintenance {
 	}
 }
 
-$maintClass = 'MathGenerateTests';
+$maintClass = MathGenerateTests::class;
 require_once RUN_MAINTENANCE_IF_MAIN;
